@@ -5,41 +5,44 @@
     SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#include <QDebug>
-#include <QDir>
+#include "kmimeassociations_p.h"
+#include "ksycoca_p.h"
+#include "setupxdgdirs.h"
 #include <KConfigGroup>
 #include <KDesktopFile>
-#include <kapplicationtrader.h>
-#include <kservicefactory_p.h>
-#include <QTemporaryDir>
-#include <QTemporaryFile>
-#include <QTest>
-#include "setupxdgdirs.h"
-#include "kmimeassociations_p.h"
-#include <kbuildsycoca_p.h>
-#include <ksycoca.h>
-#include "ksycoca_p.h"
+#include <QDebug>
+#include <QDir>
 #include <QMimeDatabase>
 #include <QMimeType>
 #include <QSignalSpy>
+#include <QTemporaryDir>
+#include <QTemporaryFile>
+#include <QTest>
+#include <kapplicationtrader.h>
+#include <kbuildsycoca_p.h>
+#include <kservicefactory_p.h>
+#include <ksycoca.h>
 
 // We need a factory that returns the same KService::Ptr every time it's asked for a given service.
 // Otherwise the changes to the service's serviceTypes by KMimeAssociationsTest have no effect
 class FakeServiceFactory : public KServiceFactory
 {
 public:
-    FakeServiceFactory(KSycoca *db) : KServiceFactory(db) {}
-    ~FakeServiceFactory();
+    FakeServiceFactory(KSycoca *db)
+        : KServiceFactory(db)
+    {
+    }
+    ~FakeServiceFactory() override;
 
     KService::Ptr findServiceByMenuId(const QString &name) override
     {
-        //qDebug() << name;
+        // qDebug() << name;
         KService::Ptr result = m_cache.value(name);
         if (!result) {
             result = KServiceFactory::findServiceByMenuId(name);
             m_cache.insert(name, result);
         }
-        //qDebug() << name << result.data();
+        // qDebug() << name << result.data();
         return result;
     }
     KService::Ptr findServiceByDesktopPath(const QString &name) override
@@ -51,14 +54,13 @@ public:
         }
         return result;
     }
+
 private:
     QMap<QString, KService::Ptr> m_cache;
 };
 
 // Helper method for all the trader tests, comes from kmimetypetest.cpp
-static bool offerListHasService(const KService::List &offers,
-                                const QString &entryPath,
-                                bool expected /* if set, show error if not found */)
+static bool offerListHasService(const KService::List &offers, const QString &entryPath, bool expected /* if set, show error if not found */)
 {
     // ksycoca resolves to canonical paths, so do it here as well
     const QString realPath = QFileInfo(entryPath).canonicalFilePath();
@@ -67,7 +69,7 @@ static bool offerListHasService(const KService::List &offers,
     bool found = false;
     for (const KService::Ptr &serv : offers) {
         if (serv->entryPath() == realPath) {
-            if (found) {  // should be there only once
+            if (found) { // should be there only once
                 qWarning("ERROR: %s was found twice in the list", qPrintable(realPath));
                 return false; // make test fail
             }
@@ -132,15 +134,15 @@ private Q_SLOTS:
         QDir(cacheDir).removeRecursively();
 
         // Create fake application (associated with text/plain in mimeapps.list)
-        fakeTextApplication = m_localApps + "faketextapplication.desktop";
+        fakeTextApplication = m_localApps + QLatin1String{"faketextapplication.desktop"};
         writeAppDesktopFile(fakeTextApplication, QStringList() << QStringLiteral("text/plain"));
 
         // Create fake application (associated with text/plain in mimeapps.list)
-        fakeTextApplicationPrefixed = m_localApps + "fakepfx/faketextapplicationpfx.desktop";
+        fakeTextApplicationPrefixed = m_localApps + QLatin1String{"fakepfx/faketextapplicationpfx.desktop"};
         writeAppDesktopFile(fakeTextApplicationPrefixed, QStringList() << QStringLiteral("text/plain"));
 
         // A fake "default" application for text/plain (high initial preference, but not in mimeapps.list)
-        fakeDefaultTextApplication = m_localApps + "fakedefaulttextapplication.desktop";
+        fakeDefaultTextApplication = m_localApps + QLatin1String{"fakedefaulttextapplication.desktop"};
         writeAppDesktopFile(fakeDefaultTextApplication, QStringList() << QStringLiteral("text/plain"), 9);
 
         // An app (like emacs) listing explicitly the derived mimetype (c-src); not in mimeapps.list
@@ -149,28 +151,31 @@ private Q_SLOTS:
         // the base mimetype is already listed.
         //
         // Also include aliases (msword), to check they don't cancel each other out.
-        fakeCSrcApplication = m_localApps + "fakecsrcmswordapplication.desktop";
-        writeAppDesktopFile(fakeCSrcApplication, QStringList() << QStringLiteral("text/plain") << QStringLiteral("text/c-src") << QStringLiteral("application/vnd.ms-word") << QStringLiteral("application/msword"), 8);
+        fakeCSrcApplication = m_localApps + QLatin1String{"fakecsrcmswordapplication.desktop"};
+        writeAppDesktopFile(fakeCSrcApplication,
+                            QStringList() << QStringLiteral("text/plain") << QStringLiteral("text/c-src") << QStringLiteral("application/vnd.ms-word")
+                                          << QStringLiteral("application/msword"),
+                            8);
 
-        fakeJpegApplication = m_localApps + "fakejpegapplication.desktop";
+        fakeJpegApplication = m_localApps + QLatin1String{"fakejpegapplication.desktop"};
         writeAppDesktopFile(fakeJpegApplication, QStringList() << QStringLiteral("image/jpeg"));
 
-        fakeArkApplication = m_localApps + "fakearkapplication.desktop";
+        fakeArkApplication = m_localApps + QLatin1String{"fakearkapplication.desktop"};
         writeAppDesktopFile(fakeArkApplication, QStringList() << QStringLiteral("application/zip"));
 
-        fakeHtmlApplication = m_localApps + "fakehtmlapplication.desktop";
+        fakeHtmlApplication = m_localApps + QLatin1String{"fakehtmlapplication.desktop"};
         writeAppDesktopFile(fakeHtmlApplication, QStringList() << QStringLiteral("text/html"));
 
-        fakeHtmlApplicationPrefixed = m_localApps + "fakepfx/fakehtmlapplicationpfx.desktop";
+        fakeHtmlApplicationPrefixed = m_localApps + QLatin1String{"fakepfx/fakehtmlapplicationpfx.desktop"};
         writeAppDesktopFile(fakeHtmlApplicationPrefixed, QStringList() << QStringLiteral("text/html"));
 
-        fakeOktetaApplication = m_localApps + "fakeoktetaapplication.desktop";
+        fakeOktetaApplication = m_localApps + QLatin1String{"fakeoktetaapplication.desktop"};
         writeAppDesktopFile(fakeOktetaApplication, QStringList() << QStringLiteral("application/octet-stream"));
 
-        const QString fakeGnomeRoller = m_localApps + "fake.org.gnome.FileRoller.desktop";
+        const QString fakeGnomeRoller = m_localApps + QLatin1String{"fake.org.gnome.FileRoller.desktop"};
         writeNonKDEAppDesktopFile(fakeGnomeRoller, QStringList() << QStringLiteral("application/x-7z-compressed"));
 
-        const QString fakeNautilus = m_localApps + "fake.org.gnome.Nautilus.desktop";
+        const QString fakeNautilus = m_localApps + QLatin1String{"fake.org.gnome.Nautilus.desktop"};
         writeNonKDEAppDesktopFile(fakeNautilus, QStringList() << QStringLiteral("application/x-7z-compressed"));
 
         // Update ksycoca in ~/.qttest after creating the above
@@ -195,37 +200,34 @@ private Q_SLOTS:
         KService::Ptr fakeApplicationService = KService::serviceByStorageId(QStringLiteral("faketextapplication.desktop"));
         QVERIFY(fakeApplicationService);
 
-        m_mimeAppsFileContents = "[Added Associations]\n"
-                                 "image/jpeg=fakejpegapplication.desktop;\n"
-                                 "text/html=fakehtmlapplication.desktop;fakehtmlapplicationpfx.desktop;\n"
-                                 "text/plain=fakepfx-faketextapplicationpfx.desktop;gvim.desktop;wine.desktop;idontexist.desktop;\n"
-                                 // test alias resolution
-                                 "application/x-pdf=fakejpegapplication.desktop;\n"
-                                 // test x-scheme-handler (#358159) (missing trailing ';' as per xdg-mime bug...)
-                                 "x-scheme-handler/mailto=faketextapplication.desktop\n"
-                                 // test association with octet-stream (#425154)
-                                 "application/octet-stream=fakeoktetaapplication.desktop\n"
-                                 // test a non-kde app (#427469)
-                                 "application/x-7z-compressed=fake.org.gnome.FileRoller.desktop;\n"
-                                 "[Added KParts/ReadOnlyPart Associations]\n"
-                                 "text/plain=katepart.desktop;\n"
-                                 "[Removed Associations]\n"
-                                 "image/jpeg=firefox.desktop;\n"
-                                 "text/html=gvim.desktop;abiword.desktop;\n"
-                                 "[Default Applications]\n"
-                                 "text/plain=faketextapplication.desktop;second-faketextapplicationpfx.desktop\n";
+        m_mimeAppsFileContents =
+            "[Added Associations]\n"
+            "image/jpeg=fakejpegapplication.desktop;\n"
+            "text/html=fakehtmlapplication.desktop;fakehtmlapplicationpfx.desktop;\n"
+            "text/plain=fakepfx-faketextapplicationpfx.desktop;gvim.desktop;wine.desktop;idontexist.desktop;\n"
+            // test alias resolution
+            "application/x-pdf=fakejpegapplication.desktop;\n"
+            // test x-scheme-handler (#358159) (missing trailing ';' as per xdg-mime bug...)
+            "x-scheme-handler/mailto=faketextapplication.desktop\n"
+            // test association with octet-stream (#425154)
+            "application/octet-stream=fakeoktetaapplication.desktop\n"
+            // test a non-kde app (#427469)
+            "application/x-7z-compressed=fake.org.gnome.FileRoller.desktop;\n"
+            "[Added KParts/ReadOnlyPart Associations]\n"
+            "text/plain=katepart.desktop;\n"
+            "[Removed Associations]\n"
+            "image/jpeg=firefox.desktop;\n"
+            "text/html=gvim.desktop;abiword.desktop;\n"
+            "[Default Applications]\n"
+            "text/plain=faketextapplication.desktop;second-faketextapplicationpfx.desktop\n";
         // Expected results
         preferredApps[QStringLiteral("image/jpeg")] << QStringLiteral("fakejpegapplication.desktop");
         preferredApps[QStringLiteral("application/pdf")] << QStringLiteral("fakejpegapplication.desktop");
-        preferredApps[QStringLiteral("text/plain")] << QStringLiteral("faketextapplication.desktop")
-                                    << QStringLiteral("second-faketextapplicationpfx.desktop")
-                                    << QStringLiteral("fakepfx-faketextapplicationpfx.desktop")
-                                    << QStringLiteral("gvim.desktop");
+        preferredApps[QStringLiteral("text/plain")] << QStringLiteral("faketextapplication.desktop") << QStringLiteral("second-faketextapplicationpfx.desktop")
+                                                    << QStringLiteral("fakepfx-faketextapplicationpfx.desktop") << QStringLiteral("gvim.desktop");
         preferredApps[QStringLiteral("text/x-csrc")] << QStringLiteral("faketextapplication.desktop")
-                                     << QStringLiteral("fakepfx-faketextapplicationpfx.desktop")
-                                     << QStringLiteral("gvim.desktop");
-        preferredApps[QStringLiteral("text/html")] << QStringLiteral("fakehtmlapplication.desktop")
-                                   << QStringLiteral("fakepfx-fakehtmlapplicationpfx.desktop");
+                                                     << QStringLiteral("fakepfx-faketextapplicationpfx.desktop") << QStringLiteral("gvim.desktop");
+        preferredApps[QStringLiteral("text/html")] << QStringLiteral("fakehtmlapplication.desktop") << QStringLiteral("fakepfx-fakehtmlapplicationpfx.desktop");
         preferredApps[QStringLiteral("application/msword")] << QStringLiteral("fakecsrcmswordapplication.desktop");
         preferredApps[QStringLiteral("x-scheme-handler/mailto")] << QStringLiteral("faketextapplication.desktop");
         preferredApps[QStringLiteral("text/x-python")] << QStringLiteral("faketextapplication.desktop");
@@ -241,7 +243,7 @@ private Q_SLOTS:
 
     void cleanupTestCase()
     {
-        QFile::remove(m_localConfig + "/mimeapps.list");
+        QFile::remove(m_localConfig + QLatin1String{"/mimeapps.list"});
         runKBuildSycoca();
     }
 
@@ -253,22 +255,21 @@ private Q_SLOTS:
         QTemporaryDir tempDir;
         QVERIFY(tempDir.isValid());
 
-        QFile tempFile(tempDir.path() + "/mimeapps.list");
+        QFile tempFile(tempDir.path() + QLatin1String{"/mimeapps.list"});
         QVERIFY(tempFile.open(QIODevice::WriteOnly));
         tempFile.write(m_mimeAppsFileContents);
         const QString fileName = tempFile.fileName();
         tempFile.close();
 
-        //QTest::ignoreMessage(QtDebugMsg, "findServiceByDesktopPath: idontexist.desktop not found");
+        // QTest::ignoreMessage(QtDebugMsg, "findServiceByDesktopPath: idontexist.desktop not found");
         parser.parseMimeAppsList(fileName, 100);
 
-        for (ExpectedResultsMap::const_iterator it = preferredApps.constBegin(),
-                end = preferredApps.constEnd(); it != end; ++it) {
+        for (auto it = preferredApps.cbegin(), endIt = preferredApps.cend(); it != endIt; ++it) {
             const QString mime = it.key();
             // The data for derived types and aliases isn't for this test (which only looks at mimeapps.list)
-            if (mime == QLatin1String("text/x-csrc")
-                    || mime == QLatin1String("text/x-python")
-                    || mime == QLatin1String("application/msword")) {
+            if (mime == QLatin1String("text/x-csrc") //
+                || mime == QLatin1String("text/x-python") //
+                || mime == QLatin1String("application/msword")) {
                 continue;
             }
             const QList<KServiceOffer> offers = offerHash.offersFor(mime);
@@ -284,14 +285,13 @@ private Q_SLOTS:
             }
         }
 
-        for (ExpectedResultsMap::const_iterator it = removedApps.constBegin(),
-                end = removedApps.constEnd(); it != end; ++it) {
+        for (auto it = removedApps.cbegin(), end = removedApps.cend(); it != end; ++it) {
             const QString mime = it.key();
             const QList<KServiceOffer> offers = offerHash.offersFor(mime);
             for (const QString &service : it.value()) {
                 KService::Ptr serv = KService::serviceByStorageId(service);
                 if (serv && offersContains(offers, serv)) {
-                    //qDebug() << serv.data() << serv->entryPath() << "does not have" << mime;
+                    // qDebug() << serv.data() << serv->entryPath() << "does not have" << mime;
                     QFAIL("offer should not have servicetype");
                 }
             }
@@ -307,12 +307,13 @@ private Q_SLOTS:
         QTemporaryDir tempDirGlobal;
         QVERIFY(tempDirGlobal.isValid());
 
-        QFile tempFileGlobal(tempDirGlobal.path() + "/mimeapps.list");
+        QFile tempFileGlobal(tempDirGlobal.path() + QLatin1String{"/mimeapps.list"});
         QVERIFY(tempFileGlobal.open(QIODevice::WriteOnly));
-        QByteArray globalAppsFileContents = "[Added Associations]\n"
-                                            "image/jpeg=firefox.desktop;\n" // removed by local config
-                                            "text/html=firefox.desktop;\n" // mdv
-                                            "image/png=fakejpegapplication.desktop;\n";
+        QByteArray globalAppsFileContents =
+            "[Added Associations]\n"
+            "image/jpeg=firefox.desktop;\n" // removed by local config
+            "text/html=firefox.desktop;\n" // mdv
+            "image/png=fakejpegapplication.desktop;\n";
         tempFileGlobal.write(globalAppsFileContents);
         const QString globalFileName = tempFileGlobal.fileName();
         tempFileGlobal.close();
@@ -321,7 +322,7 @@ private Q_SLOTS:
         QTemporaryDir tempDir;
         QVERIFY(tempDir.isValid());
 
-        QFile tempFile(tempDir.path() + "/mimeapps.list");
+        QFile tempFile(tempDir.path() + QLatin1String{"/mimeapps.list"});
         QVERIFY(tempFile.open(QIODevice::WriteOnly));
         tempFile.write(m_mimeAppsFileContents);
         const QString fileName = tempFile.fileName();
@@ -360,7 +361,7 @@ private Q_SLOTS:
 
         // Now the generic variant of the above test:
         // for each mimetype, check that the preferred apps are as specified
-        for (ExpectedResultsMap::const_iterator it = preferredApps.constBegin(), end = preferredApps.constEnd(); it != end; ++it) {
+        for (auto it = preferredApps.cbegin(), endIt = preferredApps.cend(); it != endIt; ++it) {
             const QString mime = it.key();
             const KService::List offers = KApplicationTrader::queryByMimeType(mime);
             const QStringList offerIds = assembleServices(offers, it.value().count());
@@ -373,13 +374,12 @@ private Q_SLOTS:
                 const QStringList expectedPreferredServices = it.value();
                 for (int i = 0; i < expectedPreferredServices.count(); ++i) {
                     qDebug() << mime << i << expectedPreferredServices[i];
-                    //QCOMPARE(expectedPreferredServices[i], offers[i]->storageId());
+                    // QCOMPARE(expectedPreferredServices[i], offers[i]->storageId());
                 }
             }
             QCOMPARE(offerIds, it.value());
         }
-        for (auto it = removedApps.constBegin(),
-                end = removedApps.constEnd(); it != end; ++it) {
+        for (auto it = removedApps.constBegin(), endIt = removedApps.constEnd(); it != endIt; ++it) {
             const QString mime = it.key();
             const KService::List offers = KApplicationTrader::queryByMimeType(mime);
             const QStringList offerIds = assembleServices(offers);
@@ -405,8 +405,9 @@ private Q_SLOTS:
         KService::List offers = KApplicationTrader::queryByMimeType(QStringLiteral("text/plain"));
         QVERIFY(offerListHasService(offers, fakeTextApplication, true));
 
-        writeToMimeApps(QByteArray("[Removed Associations]\n"
-                                   "text/plain=faketextapplication.desktop;\n"));
+        writeToMimeApps(
+            QByteArray("[Removed Associations]\n"
+                       "text/plain=faketextapplication.desktop;\n"));
 
         offers = KApplicationTrader::queryByMimeType(QStringLiteral("text/plain"));
         QVERIFY(!offerListHasService(offers, fakeTextApplication, false));
@@ -431,8 +432,9 @@ private Q_SLOTS:
         KService::List offers = KApplicationTrader::queryByMimeType(opendocument);
         QVERIFY(offerListHasService(offers, fakeArkApplication, true));
 
-        writeToMimeApps(QByteArray("[Removed Associations]\n"
-                                   "application/vnd.oasis.opendocument.text=fakearkapplication.desktop;\n"));
+        writeToMimeApps(
+            QByteArray("[Removed Associations]\n"
+                       "application/vnd.oasis.opendocument.text=fakearkapplication.desktop;\n"));
 
         offers = KApplicationTrader::queryByMimeType(opendocument);
         QVERIFY(!offerListHasService(offers, fakeArkApplication, false));
@@ -459,8 +461,9 @@ private Q_SLOTS:
         KService::List offers = KApplicationTrader::queryByMimeType(mime);
         QVERIFY(offerListHasService(offers, fakeArkApplication, true));
 
-        writeToMimeApps(QByteArray("[Removed Associations]\n"
-                                   "application/x-kns=fakearkapplication.desktop;\n"));
+        writeToMimeApps(
+            QByteArray("[Removed Associations]\n"
+                       "application/x-kns=fakearkapplication.desktop;\n"));
 
         offers = KApplicationTrader::queryByMimeType(mime);
         QVERIFY(!offerListHasService(offers, fakeArkApplication, false));
@@ -477,8 +480,9 @@ private Q_SLOTS:
         // get it from text/plain...
 
         KService::List offers;
-        writeToMimeApps(QByteArray("[Removed Associations]\n"
-                                   "application/x-desktop=faketextapplication.desktop;\n"));
+        writeToMimeApps(
+            QByteArray("[Removed Associations]\n"
+                       "application/x-desktop=faketextapplication.desktop;\n"));
 
         offers = KApplicationTrader::queryByMimeType(QStringLiteral("text/plain"));
         QVERIFY(offerListHasService(offers, fakeTextApplication, true));
@@ -497,7 +501,12 @@ private:
     {
         // Wait for notifyDatabaseChanged DBus signal
         // (The real KCM code simply does the refresh in a slot, asynchronously)
-        QSignalSpy spy(KSycoca::self(), SIGNAL(databaseChanged(QStringList)));
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 80)
+        QSignalSpy spy(KSycoca::self(), qOverload<const QStringList &>(&KSycoca::databaseChanged));
+#else
+        QSignalSpy spy(KSycoca::self(), &KSycoca::databaseChanged);
+#endif
+
         KBuildSycoca builder;
         QVERIFY(builder.recreate());
         if (spy.isEmpty()) {
@@ -507,7 +516,7 @@ private:
 
     void writeToMimeApps(const QByteArray &contents)
     {
-        QString mimeAppsPath = m_localConfig + "/mimeapps.list";
+        QString mimeAppsPath = m_localConfig + QLatin1String{"/mimeapps.list"};
         QFile mimeAppsFile(mimeAppsPath);
         QVERIFY(mimeAppsFile.open(QIODevice::WriteOnly));
         mimeAppsFile.write(contents);
@@ -547,11 +556,11 @@ private:
 
     void removeNonExisting(ExpectedResultsMap &erm)
     {
-        for (ExpectedResultsMap::iterator it = erm.begin(), end = erm.end(); it != end; ++it) {
+        for (auto it = erm.begin(), endIt = erm.end(); it != endIt; ++it) {
             QMutableStringListIterator serv_it(it.value());
             while (serv_it.hasNext()) {
                 if (!KService::serviceByStorageId(serv_it.next())) {
-                    //qDebug() << "removing non-existing entry" << serv_it.value();
+                    // qDebug() << "removing non-existing entry" << serv_it.value();
                     serv_it.remove();
                 }
             }
