@@ -8,6 +8,9 @@
 
 #include "kplugininfo.h"
 
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+
 #if KSERVICE_BUILD_DEPRECATED_SINCE(5, 90)
 #include "servicesdebug.h"
 #include <QDirIterator>
@@ -277,7 +280,11 @@ KPluginInfo::KPluginInfo(const QString &filename /*, QStandardPaths::StandardLoc
         return;
     }
 
-    d->setMetaData(KPluginMetaData(file.fileName()), true);
+    if (file.fileName().endsWith(QLatin1String(".desktop"))) {
+        d->setMetaData(KPluginMetaData::fromDesktopFile(file.fileName()), true);
+    } else {
+        d->setMetaData(KPluginMetaData(file.fileName()), true);
+    }
     if (!d->metaData.isValid()) {
         qCWarning(SERVICES) << "Failed to read metadata from .desktop file" << file.fileName();
         d.reset();
@@ -578,11 +585,7 @@ QString KPluginInfo::license() const
 QStringList KPluginInfo::dependencies() const
 {
     KPLUGININFO_ISVALID_ASSERTION;
-    QT_WARNING_PUSH
-    QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-    QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
     return d->metaData.dependencies();
-    QT_WARNING_POP
 }
 #endif
 
