@@ -218,7 +218,7 @@ void KServiceGroupPrivate::load(QDataStream &s)
     m_bAllowInline = (_allowInline != 0);
 
     if (m_bDeep) {
-        for (const QString &path : qAsConst(groupList)) {
+        for (const QString &path : std::as_const(groupList)) {
             if (path.endsWith(QLatin1Char('/'))) {
                 KServiceGroup::Ptr serviceGroup;
                 serviceGroup = KSycocaPrivate::self()->serviceGroupFactory()->findGroupByDesktopPath(path, false);
@@ -247,7 +247,7 @@ void KServiceGroupPrivate::save(QDataStream &s)
     KSycocaEntryPrivate::save(s);
 
     QStringList groupList;
-    for (const KSycocaEntry::Ptr &p : qAsConst(m_serviceList)) {
+    for (const KSycocaEntry::Ptr &p : std::as_const(m_serviceList)) {
         if (p->isType(KST_KService)) {
             KService::Ptr service(static_cast<KService *>(p.data()));
             groupList.append(service->entryPath());
@@ -418,12 +418,12 @@ KServiceGroup::List KServiceGroupPrivate::entries(KServiceGroup *group, bool sor
 
     // Iterate through the sort spec list.
     // If an entry gets mentioned explicitly, we remove it from the sorted list
-    for (const QString &item : qAsConst(sortOrder)) {
+    for (const QString &item : std::as_const(sortOrder)) {
         if (item.isEmpty()) {
             continue;
         }
         if (item[0] == QLatin1Char('/')) {
-            QString groupPath = rp + item.midRef(1) + QLatin1Char('/');
+            QString groupPath = rp + QStringView(item).mid(1) + QLatin1Char('/');
             // Remove entry from sorted list of services.
             for (SortedContainer::iterator it2 = glist.begin(); it2 != glist.end(); ++it2) {
                 const KServiceGroup::Ptr group(static_cast<KServiceGroup *>(it2.value().data()));
@@ -528,7 +528,7 @@ KServiceGroup::List KServiceGroupPrivate::entries(KServiceGroup *group, bool sor
                 }
             }
         } else if (item[0] == QLatin1Char('/')) {
-            QString groupPath = rp + item.midRef(1) + QLatin1Char('/');
+            QString groupPath = rp + QStringView(item).mid(1) + QLatin1Char('/');
 
             for (KServiceGroup::List::ConstIterator it2(group->d_func()->m_serviceList.constBegin()); it2 != group->d_func()->m_serviceList.constEnd(); ++it2) {
                 if (!(*it2)->isType(KST_KServiceGroup)) {
@@ -552,7 +552,7 @@ KServiceGroup::List KServiceGroupPrivate::entries(KServiceGroup *group, bool sor
                             bool bShowInlineHeader = false;
                             bool bShowInlineAlias = false;
                             int inlineValue = -1;
-                            for (const QString &opt_attr : qAsConst(optionAttribute)) {
+                            for (const QString &opt_attr : std::as_const(optionAttribute)) {
                                 parseAttribute(opt_attr, bShowEmptyMenu, bShowInline, bShowInlineHeader, bShowInlineAlias, inlineValue);
                                 group->setShowEmptyMenu(bShowEmptyMenu);
                                 group->setAllowInline(bShowInline);
@@ -611,7 +611,7 @@ void KServiceGroupPrivate::parseAttribute(const QString &item,
         showInlineAlias = true;
     } else if (item == QLatin1String("NIA")) { // not inline alias!
         showInlineAlias = false;
-    } else if ((item).contains(QLatin1String("IL"))) { // inline limite!
+    } else if ((item).contains(QLatin1String("IL"))) { // inline limit!
         QString tmp(item);
         tmp.remove(QStringLiteral("IL["));
         tmp.remove(QLatin1Char(']'));
