@@ -8,6 +8,8 @@
 
 #include "kservicetypetrader.h"
 
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 90)
+
 #include "kservicefactory_p.h"
 #include "kservicetype.h"
 #include "kservicetypefactory_p.h"
@@ -64,14 +66,11 @@ void KServiceTypeTrader::applyConstraints(KService::List &lst, const QString &co
     } else {
         // Find all services matching the constraint
         // and remove the other ones
-        KService::List::iterator it = lst.begin();
-        while (it != lst.end()) {
-            if (matchConstraint(pConstraintTree, (*it), lst) != 1) {
-                it = lst.erase(it);
-            } else {
-                ++it;
-            }
-        }
+        auto isMatch = [=](const KService::Ptr &service) {
+            return matchConstraint(pConstraintTree, service, lst) != 1;
+        };
+
+        lst.erase(std::remove_if(lst.begin(), lst.end(), isMatch), lst.end());
     }
 }
 
@@ -162,3 +161,5 @@ KService::Ptr KServiceTypeTrader::preferredService(const QString &serviceType) c
     // qDebug() << "No offers, or none allowed as default";
     return KService::Ptr();
 }
+
+#endif
