@@ -69,7 +69,7 @@ KSycocaEntry *KBuildServiceFactory::createEntry(const QString &file) const
 {
     Q_ASSERT(!file.startsWith(QLatin1String("kservices5/"))); // we add this ourselves, below
 
-    const QStringRef name = file.midRef(file.lastIndexOf(QLatin1Char('/')) + 1);
+    const QStringView name = QStringView(file).mid(file.lastIndexOf(QLatin1Char('/')) + 1);
 
     // Is it a .desktop file?
     if (name.endsWith(QLatin1String(".desktop"))) {
@@ -191,18 +191,18 @@ void KBuildServiceFactory::postProcessServices()
     // storage ID) have been removed.
 
     // For every service...
-    KSycocaEntryDict::const_iterator itserv = m_entryDict->constBegin();
-    const KSycocaEntryDict::const_iterator endserv = m_entryDict->constEnd();
-    for (; itserv != endserv; ++itserv) {
-        KSycocaEntry::Ptr entry = *itserv;
+    for (auto itserv = m_entryDict->cbegin(), endIt = m_entryDict->cend(); itserv != endIt; ++itserv) {
+        KSycocaEntry::Ptr entry = itserv.value();
         KService::Ptr service(static_cast<KService *>(entry.data()));
 
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 87)
         if (!service->isDeleted()) {
             const QString parent = service->parentApp();
             if (!parent.isEmpty()) {
                 m_serviceGroupFactory->addNewChild(parent, KSycocaEntry::Ptr(service));
             }
         }
+#endif
 
         const QString name = service->desktopEntryName();
         KService::Ptr dup = m_nameMemoryHash.value(name);
@@ -242,10 +242,10 @@ void KBuildServiceFactory::populateServiceTypes()
 {
     QMimeDatabase db;
     // For every service...
-    KSycocaEntryDict::const_iterator itserv = m_entryDict->constBegin();
-    const KSycocaEntryDict::const_iterator endserv = m_entryDict->constEnd();
-    for (; itserv != endserv; ++itserv) {
-        KService::Ptr service(static_cast<KService *>((*itserv).data()));
+    auto servIt = m_entryDict->cbegin();
+    const auto endIt = m_entryDict->cend();
+    for (; servIt != endIt; ++servIt) {
+        KService::Ptr service(static_cast<KService *>(servIt.value().data()));
         const bool hidden = !service->showInCurrentDesktop();
         QVector<KService::ServiceTypeAndPreference> serviceTypeList = service->_k_accessServiceTypes();
         // bool hasAllAll = false;
